@@ -12,6 +12,7 @@ from trytond.tests.test_tryton import ModuleTestCase, with_transaction
 from trytond.tests.test_tryton import doctest_teardown
 from trytond.tests.test_tryton import doctest_checker
 from trytond.pool import Pool
+from trytond.exceptions import UserError
 from trytond.transaction import Transaction
 
 
@@ -102,6 +103,31 @@ class PartyTestCase(ModuleTestCase):
                 "St sample, 15\n"
                 "City")
 
+    @with_transaction()
+    def test_full_address_country_subdivision(self):
+        'Test full address with country and subdivision'
+        pool = Pool()
+        Party = pool.get('party.party')
+        Country = pool.get('country.country')
+        Subdivision = pool.get('country.subdivision')
+        Address = pool.get('party.address')
+        party, = Party.create([{
+                    'name': 'Party',
+                    }])
+        country = Country(name='Country')
+        country.save()
+        subdivision = Subdivision(
+            name='Subdivision', country=country, code='SUB', type='area')
+        subdivision.save()
+        address, = Address.create([{
+                    'party': party.id,
+                    'subdivision': subdivision.id,
+                    'country': country.id,
+                    }])
+        self.assertMultiLineEqual(address.full_address,
+            "Subdivision\n"
+            "COUNTRY")
+
     @with_transaction()
     def test_party_label_report(self):
         'Test party label report'
@@ -132,17 +158,20 @@ class PartyTestCase(ModuleTestCase):
         pool = Pool()
         Party = pool.get('party.party')
         ContactMechanism = pool.get('party.contact_mechanism')
+        transaction = Transaction()
 
-        party1, = Party.create([{
-                    'name': 'Party 1',
-                    }])
-        mechanism, = ContactMechanism.create([{
-                    'party': party1.id,
-                    'type': 'phone',
-                    'value': '+442083661177',
-                    }])
+        def create(mtype, mvalue):
+            party1, = Party.create([{
+                        'name': 'Party 1',
+                        }])
+            return ContactMechanism.create([{
+                        'party': party1.id,
+                        'type': mtype,
+                        'value': mvalue,
+                        }])[0]
 
         # Test format on create
+        mechanism = create('phone', '+442083661177')
         self.assertEqual(mechanism.value, '+44 20 8366 1177')
         self.assertEqual(mechanism.value_compact, '+442083661177')
 
@@ -158,6 +187,20 @@ class PartyTestCase(ModuleTestCase):
         self.assertEqual(mechanism.value, '+44 20 8366 1179')
         self.assertEqual(mechanism.value_compact, '+442083661179')
 
+        # Test rejection of a phone type mechanism to non-phone value
+        with self.assertRaises(UserError):
+            mechanism.value = 'notaphone@example.com'
+            mechanism.save()
+        transaction.rollback()
+
+        # Test rejection of invalid phone number creation
+        with self.assertRaises(UserError):
+            mechanism = create('phone', 'alsonotaphone@example.com')
+        transaction.rollback()
+
+        # Test acceptance of a non-phone value when type is non-phone
+        mechanism = create('email', 'name@example.com')
+
 
 def suite():
     suite = trytond.tests.test_tryton.suite()
